%% sims020316b.m
%% adapted from sims020316a.m
%%
%% Looking at two-good robust problems, and generating a bunch of random
%% distributions, and asking:
%% How often are we pinned down to separate revenue if we know the
%% correlation of values is negative?
%% Using five-value distributions and MaxIter = 4000, and simplex algorithm
%% instead of default interior-point algorithm.

diary 'sims020316b.log';

revtol = 0.0001;
numtrials = 1000;
valuesa = [1,2,3,4,5];
ka = 5;
valuesb = [1,2,3,4,5];
kb = 5;
valueprods = valuesa'*valuesb;
helddown = 0;
errorcount = 0;
mi = 4000;

%% for each trial: record
%% (1) if we are pinned down to sep revenue
%% (2) if we are pinned down when corr is negative
%% (3) if we are pinned down when corr is positive

for trial = 1:numtrials
    probsa = rand(1,ka);
    probsa = probsa/sum(probsa);
    probsb = rand(1,kb);
    probsb = probsb/sum(probsb);
    meana = probsa*valuesa';
    meanb = probsb*valuesb';
    meanprod = meana*meanb;
    [r,m,wc,sr] = twogoodoptonecnsmis(valuesa,probsa,valuesb,probsb,-valueprods,-meanprod,mi);
    if (abs(r - sr) < revtol)
        helddown = helddown + 1;
    end;
    if r < sr - revtol
        errorcount = errorcount + 1;
    end;
end;
disp('Number of trials:');
disp(numtrials);
disp('Number of times negative correlation holds us down to separate-sales revenue:');
disp(helddown);
disp('Number of times negative correlation apparently yields below separate-sales revenue:');
disp(errorcount);

diary OFF;

        